summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoMainWindow.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'lib/kofficecore/KoMainWindow.cpp')
-rw-r--r--lib/kofficecore/KoMainWindow.cpp78
1 files changed, 39 insertions, 39 deletions
diff --git a/lib/kofficecore/KoMainWindow.cpp b/lib/kofficecore/KoMainWindow.cpp
index 12e0013d..f013ca36 100644
--- a/lib/kofficecore/KoMainWindow.cpp
+++ b/lib/kofficecore/KoMainWindow.cpp
@@ -144,16 +144,16 @@ public:
TQLabel * statusBarLabel;
KProgress *m_progress;
- TQPtrList<KAction> m_splitViewActionList;
+ TQPtrList<TDEAction> m_splitViewActionList;
// This additional list is needed, because we don't plug
// the first list, when an embedded view gets activated (Werner)
- TQPtrList<KAction> m_veryHackyActionList;
+ TQPtrList<TDEAction> m_veryHackyActionList;
TQSplitter *m_splitter;
- KSelectAction *m_orientation;
- KAction *m_removeView;
+ TDESelectAction *m_orientation;
+ TDEAction *m_removeView;
KoMainWindowIface *m_dcopObject;
- TQPtrList <KAction> m_toolbarList;
+ TQPtrList <TDEAction> m_toolbarList;
bool bMainWindowGUIBuilt;
bool m_splitted;
@@ -161,17 +161,17 @@ public:
bool m_firstTime;
bool m_windowSizeDirty;
- KAction *m_paDocInfo;
- KAction *m_paSave;
- KAction *m_paSaveAs;
- KAction *m_paPrint;
- KAction *m_paPrintPreview;
- KAction *m_sendfile;
- KAction *m_paCloseFile;
- KAction *m_reloadfile;
- KAction *m_versionsfile;
- KAction *m_importFile;
- KAction *m_exportFile;
+ TDEAction *m_paDocInfo;
+ TDEAction *m_paSave;
+ TDEAction *m_paSaveAs;
+ TDEAction *m_paPrint;
+ TDEAction *m_paPrintPreview;
+ TDEAction *m_sendfile;
+ TDEAction *m_paCloseFile;
+ TDEAction *m_reloadfile;
+ TDEAction *m_versionsfile;
+ TDEAction *m_importFile;
+ TDEAction *m_exportFile;
bool m_isImporting;
bool m_isExporting;
@@ -217,24 +217,24 @@ KoMainWindow::KoMainWindow( TDEInstance *instance, const char* name )
d->m_paCloseFile = KStdAction::close( TQT_TQOBJECT(this), TQT_SLOT( slotFileClose() ), actionCollection(), "file_close" );
KStdAction::quit( TQT_TQOBJECT(this), TQT_SLOT( slotFileQuit() ), actionCollection(), "file_quit" );
- d->m_reloadfile = new KAction( i18n( "Reload"), 0,
+ d->m_reloadfile = new TDEAction( i18n( "Reload"), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotReloadFile() ),
actionCollection(), "file_reload_file");
- d->m_versionsfile = new KAction( i18n( "Versions..."), 0,
+ d->m_versionsfile = new TDEAction( i18n( "Versions..."), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotVersionsFile() ),
actionCollection(), "file_versions_file");
- d->m_importFile = new KAction( i18n( "I&mport..." ), 0, // clashing accel key :(
+ d->m_importFile = new TDEAction( i18n( "I&mport..." ), 0, // clashing accel key :(
TQT_TQOBJECT(this), TQT_SLOT( slotImportFile() ),
actionCollection(), "file_import_file");
- d->m_exportFile = new KAction( i18n( "E&xport..." ), 0,
+ d->m_exportFile = new TDEAction( i18n( "E&xport..." ), 0,
TQT_TQOBJECT(this), TQT_SLOT( slotExportFile() ),
actionCollection(), "file_export_file");
/* The following entry opens the document information dialog. Since the action is named so it
intends to show data this entry should not have a trailing ellipses (...). */
- d->m_paDocInfo = new KAction( i18n( "&Document Information" ), "documentinfo", 0,
+ d->m_paDocInfo = new TDEAction( i18n( "&Document Information" ), "documentinfo", 0,
TQT_TQOBJECT(this), TQT_SLOT( slotDocumentInfo() ),
actionCollection(), "file_documentinfo" );
@@ -259,20 +259,20 @@ KoMainWindow::KoMainWindow( TDEInstance *instance, const char* name )
new KKbdAccessExtensions(this, "mw-panelSizer");
// set up the action "list" for "Close all Views" (hacky :) (Werner)
d->m_veryHackyActionList.append(
- new KAction(i18n("&Close All Views"), "fileclose",
+ new TDEAction(i18n("&Close All Views"), "fileclose",
"ctrl+shift+w", TQT_TQOBJECT(this), TQT_SLOT(slotCloseAllViews()),
actionCollection(), "view_closeallviews") );
// set up the action list for the splitter stuff
- d->m_splitViewActionList.append(new KAction(i18n("&Split View"), "view_split", 0,
+ d->m_splitViewActionList.append(new TDEAction(i18n("&Split View"), "view_split", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotSplitView()),
actionCollection(), "view_split"));
- d->m_removeView=new KAction(i18n("&Remove View"), "view_remove", 0,
+ d->m_removeView=new TDEAction(i18n("&Remove View"), "view_remove", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotRemoveView()),
actionCollection(), "view_rm_splitter");
d->m_splitViewActionList.append(d->m_removeView);
d->m_removeView->setEnabled(false);
- d->m_orientation=new KSelectAction(i18n("Splitter &Orientation"), "view_orientation", 0,
+ d->m_orientation=new TDESelectAction(i18n("Splitter &Orientation"), "view_orientation", 0,
TQT_TQOBJECT(this), TQT_SLOT(slotSetOrientation()),
actionCollection(), "view_splitter_orientation");
TQStringList items;
@@ -281,7 +281,7 @@ KoMainWindow::KoMainWindow( TDEInstance *instance, const char* name )
d->m_orientation->setItems(items);
d->m_orientation->setCurrentItem(static_cast<int>(d->m_splitter->orientation()));
d->m_splitViewActionList.append(d->m_orientation);
- d->m_splitViewActionList.append(new KActionSeparator(TQT_TQOBJECT(this)));
+ d->m_splitViewActionList.append(new TDEActionSeparator(TQT_TQOBJECT(this)));
// Load list of recent files
TDEConfig * config = instance ? instance->config() : TDEGlobal::config();
@@ -448,10 +448,10 @@ void KoMainWindow::addRecentURL( const KURL& url )
if ( path.contains( *it ) )
ok = false; // it's in the tmp resource
if ( ok )
- KRecentDocument::add(path);
+ TDERecentDocument::add(path);
}
else
- KRecentDocument::add(url.url(-1), true);
+ TDERecentDocument::add(url.url(-1), true);
if ( ok )
m_recent->addURL( url );
@@ -466,12 +466,12 @@ void KoMainWindow::saveRecentFiles()
kdDebug(30003) << this << " Saving recent files list into config. instance()=" << instance() << endl;
m_recent->saveEntries( config );
config->sync();
- if (KMainWindow::memberList)
+ if (TDEMainWindow::memberList)
{
// Tell all windows to reload their list, after saving
// Doesn't work multi-process, but it's a start
- KMainWindow *window = KMainWindow::memberList->first();
- for (; window; window = KMainWindow::memberList->next())
+ TDEMainWindow *window = TDEMainWindow::memberList->first();
+ for (; window; window = TDEMainWindow::memberList->next())
static_cast<KoMainWindow *>(window)->reloadRecentFileList();
}
}
@@ -1000,7 +1000,7 @@ void KoMainWindow::saveWindowSettings()
//kdDebug(30003) << "KoMainWindow::closeEvent -> saveMainWindowSettings rootdoc's instance=" << rootDocument()->instance()->instanceName() << endl;
saveMainWindowSettings( TDEGlobal::config(), rootDocument()->instance()->instanceName() );
TDEGlobal::config()->sync();
- resetAutoSaveSettings(); // Don't let KMainWindow override the good stuff we wrote down
+ resetAutoSaveSettings(); // Don't let TDEMainWindow override the good stuff we wrote down
}
}
@@ -1306,7 +1306,7 @@ void KoMainWindow::slotToolbarToggled( bool toggle )
{
//kdDebug(30003) << "KoMainWindow::slotToolbarToggled " << sender()->name() << " toggle=" << true << endl;
// The action (sender) and the toolbar have the same name
- KToolBar * bar = toolBar( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
+ TDEToolBar * bar = toolBar( TQT_TQOBJECT(const_cast<TQT_BASE_OBJECT_NAME*>(sender()))->name() );
if (bar)
{
if (toggle)
@@ -1341,12 +1341,12 @@ void KoMainWindow::showToolbar( const char * tbName, bool shown )
tb->hide();
// Update the action appropriately
- TQPtrListIterator<KAction> it( d->m_toolbarList );
+ TQPtrListIterator<TDEAction> it( d->m_toolbarList );
for ( ; it.current() ; ++it )
if ( !strcmp( it.current()->name(), tbName ) )
{
//kdDebug(30003) << "KoMainWindow::showToolbar setChecked " << shown << endl;
- static_cast<KToggleAction *>(it.current())->setChecked( shown );
+ static_cast<TDEToggleAction *>(it.current())->setChecked( shown );
break;
}
}
@@ -1521,15 +1521,15 @@ void KoMainWindow::slotActivePartChanged( KParts::Part *newPart )
setAutoSaveSettings( newPart->instance()->instanceName(), false );
// Create and plug toolbar list for Settings menu
- //TQPtrListIterator<KToolBar> it = toolBarIterator();
+ //TQPtrListIterator<TDEToolBar> it = toolBarIterator();
TQPtrList<TQWidget> toolBarList = factory->containers( "ToolBar" );
TQPtrListIterator<TQWidget> it( toolBarList );
for ( ; it.current() ; ++it )
{
- if ( it.current()->inherits("KToolBar") )
+ if ( it.current()->inherits("TDEToolBar") )
{
- KToolBar * tb = static_cast<KToolBar *>(it.current());
- KToggleAction * act = new KToggleAction( i18n("Show %1 Toolbar").arg( tb->text() ), 0,
+ TDEToolBar * tb = static_cast<TDEToolBar *>(it.current());
+ TDEToggleAction * act = new TDEToggleAction( i18n("Show %1 Toolbar").arg( tb->text() ), 0,
actionCollection(), tb->name() );
act->setCheckedState(i18n("Hide %1 Toolbar").arg( tb->text() ));
connect( act, TQT_SIGNAL( toggled( bool ) ), TQT_TQOBJECT(this), TQT_SLOT( slotToolbarToggled( bool ) ) );